## Load an existing model
* Provide the path to a model file (typically a .h5, .json or .model file)

## Model weights
* **Optional**: you can load weights to be applied to the model (the architecture of the model and the weights must match one to one or an error will occur). Usually model weigths are provided as a .h5 file.

## Create the model
* Press 'Go' to load the model (Note that loading a model can take a lot of time, up to several minutes so please be patient).